==> apimodule-1.0.5.tar.gz: lib/msimpersaa/response/penempatan_response.dart <==
class PenempatanResponse {
  bool con;
  String msg;
  List<PenempatanResults> results;

  PenempatanResponse({this.con, this.msg, this.results});

  PenempatanResponse.fromJson(Map<String, dynamic> json) {
    con = json['con'];
    msg = json['msg'];
    if (json['results'] != null) {
      results = <PenempatanResults>[];
      json['results'].forEach((v) {
        results.add(PenempatanResults.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['con'] = this.con;
    data['msg'] = this.msg;
    if (this.results != null) {
      data['results'] = this.results.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class PenempatanResults {
  int id;
  String nomorSurat;
  String tanggalSurat;
  String unitKerja;
  String penempatan;
  String sdmRumpun;
  String sdmSubRumpun;
  String sdmJenis;
  String documen;
  String pathFile;

  PenempatanResults(
      {this.id,
      this.nomorSurat,
      this.tanggalSurat,
      this.unitKerja,
      this.penempatan,
      this.sdmRumpun,
      this.sdmSubRumpun,
      this.sdmJenis,
      this.documen,
      this.pathFile});

  PenempatanResults.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    nomorSurat = json['nomor_surat'];
    tanggalSurat = json['tanggal_surat'];
    unitKerja = json['unit_kerja'];
    penempatan = json['penempatan'];
    sdmRumpun = json['sdm_rumpun'];
    sdmSubRumpun = json['sdm_sub_rumpun'];
    sdmJenis = json['sdm_jenis'];
    documen = json['dokumen'];
    pathFile = json['path_file'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['id'] = this.id;
    data['nomor_surat'] = this.nomorSurat;
    data['tanggal_surat'] = this.tanggalSurat;
    data['unit_kerja'] = this.unitKerja;
    data['penempatan'] = this.penempatan;
    data['sdm_rumpun'] = this.sdmRumpun;
    data['sdm_sub_rumpun'] = this.sdmSubRumpun;
    data['sdm_jenis'] = this.sdmJenis;
    data['dokumen'] = this.documen;
    data['path_file'] = this.pathFile;
    return data;
  }
}

==> apimodule-1.1.5.tar.gz: lib/msimpersaa/response/penempatan_response.dart <==
class PenempatanResponse {
  bool con;
  String msg;
  List<PenempatanResults> results;

  PenempatanResponse({this.con, this.msg, this.results});

  PenempatanResponse.fromJson(Map<String, dynamic> json) {
    con = json['con'];
    msg = json['msg'];
    if (json['results'] != null) {
      results = <PenempatanResults>[];
      json['results'].forEach((v) {
        results.add(PenempatanResults.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['con'] = this.con;
    data['msg'] = this.msg;
    if (this.results != null) {
      data['results'] = this.results.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class PenempatanResults {
  int id;
  String nomorSurat;
  String tanggalSurat;
  String unitKerja;
  String penempatan;
  String sdmRumpun;
  String sdmSubRumpun;
  String sdmJenis;
  String document;
  String pathFile;

  PenempatanResults(
      {this.id,
      this.nomorSurat,
      this.tanggalSurat,
      this.unitKerja,
      this.penempatan,
      this.sdmRumpun,
      this.sdmSubRumpun,
      this.sdmJenis,
      this.document,
      this.pathFile});

  PenempatanResults.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    nomorSurat = json['nomor_surat'];
    tanggalSurat = json['tanggal_surat'];
    unitKerja = json['unit_kerja'];
    penempatan = json['penempatan'];
    sdmRumpun = json['sdm_rumpun'];
    sdmSubRumpun = json['sdm_sub_rumpun'];
    sdmJenis = json['sdm_jenis'];
    document = json['dokumen'];
    pathFile = json['path_file'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['id'] = this.id;
    data['nomor_surat'] = this.nomorSurat;
    data['tanggal_surat'] = this.tanggalSurat;
    data['unit_kerja'] = this.unitKerja;
    data['penempatan'] = this.penempatan;
    data['sdm_rumpun'] = this.sdmRumpun;
    data['sdm_sub_rumpun'] = this.sdmSubRumpun;
    data['sdm_jenis'] = this.sdmJenis;
    data['dokumen'] = this.document;
    data['path_file'] = this.pathFile;
    return data;
  }
}
